package controllers

import (
	"log"
	"main/mvc/models"
	models_pages "main/mvc/models/pages"
	"main/tools"
	"net/http"
)

// Обработчик главной страницы
func MainPageHandler(a *models.App) http.HandlerFunc {
	return http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {

		var err error

		// Количество запросов, обработанных сервером за 24ч
		if r.Method == "COUNT" {
			var count []byte
			if count, err = tools.GetJournalctlLogs("server", "hikan.ru", 24); err != nil {
				log.Printf("%s", err.Error())
			}
			SendCount(w, count)
			return
		}

		// Пасхалка
		if r.Method == "LOVE" {
			SendLove(w)
			return
		}

		// Страничка рендерится только если ее нет в кэше
		pageData, ok := a.Cache.Get(models_pages.MainPageTmplName)
		if !ok {
			pageData, err = models_pages.RenderMainPage(a.Templates, a.Version)
			if err != nil {
				http.Error(w, err.Error(), http.StatusInternalServerError)
				return
			}
			a.Cache.Set(models_pages.MainPageTmplName, pageData)
		}

		SendMainPage(w, pageData.([]byte))
	})
}

// Отправляет страницу
func SendMainPage(w http.ResponseWriter, data []byte) {
	w.Header().Set("Content-Type", "text/html; charset=utf-8")
	w.WriteHeader(http.StatusOK)
	w.Write(data)
}

// Ответ на метод COUNT
func SendCount(w http.ResponseWriter, data []byte) {
	w.Header().Set("Content-Type", "text/plain; charset=utf-8")
	w.WriteHeader(http.StatusOK)
	w.Write(data)
}

// Ответ на метод LOVE
func SendLove(w http.ResponseWriter) {
	w.Header().Set("Content-Type", "text/plain; charset=utf-8")
	w.WriteHeader(http.StatusOK)
	w.Write([]byte("13.01.2005"))
}
